==> seedsui-react-2.6.2.tgz: package/es/Badge/Badge.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Badge = (_temp = _class = function (_Component) {
  _inherits(Badge, _Component);

  function Badge(props) {
    _classCallCheck(this, Badge);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {};
    return _this;
  }

  Badge.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        className = _props.className,
        style = _props.style,
        children = _props.children,
        limit = _props.limit,
        ellipsis = _props.ellipsis,
        others = _objectWithoutProperties(_props, ['className', 'style', 'children', 'limit', 'ellipsis']);
    // 标题


    var caption = children;
    // 自动宽度,当大于两位时变宽
    var autoWidthClass = '';
    if (children && (typeof children === 'string' || typeof children === 'number')) {
      // 数字大于99,则显示99+
      if (!isNaN(children)) {
        caption = children.length > limit ? '99999'.substring(0, limit) + ellipsis : children;
      }
      // 数字大于2位以及2位以上,显示最大宽度
      autoWidthClass = children.length >= 2 ? 'badge-max-width' : '';
    }
    return React.createElement(
      'span',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'badge' + (autoWidthClass ? ' ' + autoWidthClass : '') + (className ? ' ' + className : ''), style: style }, others),
      caption
    );
  };

  return Badge;
}(Component), _class.defaultProps = {
  children: '0',
  limit: 2,
  ellipsis: '+'
}, _temp);
export { Badge as default };
Badge.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  style: PropTypes.object,
  children: PropTypes.node,
  limit: PropTypes.number,
  ellipsis: PropTypes.string
} : {};

==> seedsui-react-2.7.9.tgz: package/es/Badge/Badge.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Badge = (_temp = _class = function (_Component) {
  _inherits(Badge, _Component);

  function Badge(props) {
    _classCallCheck(this, Badge);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Badge.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        children = _props.children,
        limit = _props.limit,
        ellipsis = _props.ellipsis,
        others = _objectWithoutProperties(_props, ['children', 'limit', 'ellipsis']);
    // 标题


    var caption = children;
    // 自动宽度,当大于两位时变宽
    var autoWidthClass = '';
    if (limit && children && (typeof children === 'string' || typeof children === 'number')) {
      // 数字大于99,则显示99+
      if (!isNaN(children)) {
        caption = children.length > limit ? '99999'.substring(0, limit) + ellipsis : children;
      } else {
        caption = children.length > limit ? children.substring(0, limit) + ellipsis : children;
      }
      // 数字大于2位以及2位以上,显示最大宽度
      autoWidthClass = children.length >= 2 ? 'badge-max-width' : '';
    }
    return React.createElement(
      'span',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'badge' + (autoWidthClass ? ' ' + autoWidthClass : '') + (others.className ? ' ' + others.className : '') }),
      caption
    );
  };

  return Badge;
}(Component), _class.defaultProps = {
  children: '0',
  limit: 2,
  ellipsis: '+'
}, _temp);
export { Badge as default };
Badge.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node,
  limit: PropTypes.number,
  ellipsis: PropTypes.string // 有limit属性时ellipsis才生效
} : {};
